package com.cnooc.edgeapp.controller;

import com.alibaba.fastjson.JSONObject;
import com.cnooc.edgeapp.dto.CompletionReport;
import com.cnooc.edgeapp.dto.CompletionReportDto;
import com.cnooc.edgeapp.dto.ConstructionAttebdabceDetail;
import com.cnooc.edgeapp.dto.ConstructionAttebdabceDetailInteractive;
import com.cnooc.edgeapp.dto.ConstructionDailyReportDto;
import com.cnooc.edgeapp.dto.ConstructionEducationDetailDto;
import com.cnooc.edgeapp.dto.ContractorPersonnelDto;
import com.cnooc.edgeapp.dto.PreConstructionInspectionDto;
import com.cnooc.edgeapp.query.ConstructionPlanDetailQuery;
import com.cnooc.edgeapp.query.ConstructionProblemsQuery;
import com.cnooc.edgeapp.query.ConstructionStartFlowLogComplementQuery;
import com.cnooc.edgeapp.query.ContractorLoginQuery;
import com.cnooc.edgeapp.query.EvaluationSignatureQuery;
import com.cnooc.edgeapp.query.PerformanceSignaturePdaQuery;
import com.cnooc.edgeapp.query.StartConfirmationQuery;
import com.cnooc.edgeapp.service.LoginService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @program: sam-01
 * @description:
 * @author: niujie
 * @create: 2022-10-12 14:10
 */
@RestController
@RequestMapping("/constructionPda")
@CrossOrigin
public class ConstructionPdaController {
    private static final Logger log = LoggerFactory.getLogger(ConstructionPdaController.class);

    @Value("${url}")
    public String url;

    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    @Autowired
    private LoginService loginService;

    /**
     * 承包商登陆查询
     * @param contractorName 承包商姓名
     * @param contractorPhone 承包商电话
     * @return
     */
    @GetMapping("/contractor/getProject")
    public Object getProject(String contractorName, String contractorPhone) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = null;
        try {
            exchange = restTemplate.exchange(url + "constructionPda/contractor/getProject?contractorName="+contractorName + "&contractorPhone=" + contractorPhone, HttpMethod.GET, entity, Object.class);
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
        return exchange;
    }

    /**
     * 承包商登陆
     * @param
     * @return
     */
    @PostMapping("/contractor/login")
    public Object contractorLogin(@RequestBody ContractorLoginQuery contractorLoginQuery) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(contractorLoginQuery);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/login", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商人员列表
     * @param projectNo
     * @return
     */
    @GetMapping("/contractor/userInformation")
    public Object queryContractorUser(String projectNo, String platId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/userInformation?projectNo="+projectNo + "&platform=" + platId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商人员新增
     * @param contractorPersonnelDto
     * @return
     */
    @PostMapping("/contractor/saveContractorUser")
    public Object saveContractorUser(@RequestBody ContractorPersonnelDto contractorPersonnelDto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(contractorPersonnelDto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/saveContractorUser", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商人员修改
     * @param contractorPersonnelDto
     * @return
     */
    @PostMapping("/contractor/updateContractorUser")
    public Object updateContractorUser(@RequestBody ContractorPersonnelDto contractorPersonnelDto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(contractorPersonnelDto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/updateContractorUser", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商人员删除
     * @param id
     * @return
     */
    @GetMapping("/contractor/deleteContractorUser")
    public Object deleteContractorUser(@RequestParam("id") String id) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/deleteContractorUser?id="+id, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商启动
     * @param projectNo
     * @return
     */
    @GetMapping("/contractor/startProject")
    public Object startProject(@RequestParam("projectNo") String projectNo,
                               @RequestParam("seaLand") String seaLand,
                               @RequestParam("platformId") String platformId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/startProject?projectNo="+projectNo+"&seaLand="+seaLand+"&platformId="+platformId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工启动查看审批详情
     * @return
     */
    @GetMapping("/contractor/queryConstructionStartFlowLog")
    public Object queryConstructionStartFlowLog(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/queryConstructionStartFlowLog?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商计划查询
     * @param projectNo
     * @return
     */
    @GetMapping("/contractor/getProjectPlan")
    public Object getProjectPlan(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/getProjectPlan?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商计划新建
     * @param constructionPlanDetailQuery
     * @return
     */
    @PostMapping("/contractor/saveProjectPlan")
    public Object saveProjectPlan(@RequestBody ConstructionPlanDetailQuery constructionPlanDetailQuery) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(constructionPlanDetailQuery);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/saveProjectPlan", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商启动完工评价
     * @param
     * @return
     */
    @GetMapping("/contractor/evaluationStart")
    public Object evaluationStart(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/evaluationStart?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商施工评价查看详情
     * @return
     */
    @GetMapping("/contractor/queryEvaluationStart")
    public Object queryEvaluationStart(@RequestParam("projectNo") String projectNo) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = null;
        try {
            exchange = restTemplate.exchange(url + "constructionPda/contractor/queryEvaluationStart?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
        return exchange;
    }

    /**
     * 承包商保存施工完工报告
     * @return
     */
    @PostMapping("/contractor/saveCompletionReport")
    public Object saveCompletionReport(@RequestBody CompletionReport completionReport) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(completionReport);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/saveCompletionReport", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员录入项目问题
     * @param
     * @return
     */
    @PostMapping("/contractor/constructionProblems")
    public Object constructionProblems(@RequestBody ConstructionProblemsQuery constructionProblemsQuery) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(constructionProblemsQuery);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/constructionProblems", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员查看项目问题
     * @param
     * @return
     */
    @GetMapping("/contractor/getConstructionProblems")
    public Object getConstructionProblems(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/contractor/getConstructionProblems?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 完工报告确认
     * @return
     */
    @PostMapping("/construction/approveCompletionReport")
    Object approveCompletionReport(@RequestBody CompletionReportDto completionReport) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(completionReport);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/construction/approveCompletionReport", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工评价查看详情
     * @return
     */
    @GetMapping("/construction/queryEvaluationPerformance")
    public Object queryEvaluationPerformance(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/construction/queryEvaluationPerformance?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工绩效查看详情
     * @return
     */
    @GetMapping("/construction/queryPerformance")
    public Object queryPerformance(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/construction/queryPerformance?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工评价签字确认
     * @return
     */
    @PostMapping("/construction/evaluationSignature")
    public Object evaluationSignature(@RequestBody List<EvaluationSignatureQuery> evaluationSignatureQuerys) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(evaluationSignatureQuerys);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/construction/evaluationSignature", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 绩效结算
     * @return
     */
    @PostMapping("/construction/performanceSignature")
    public Object performanceSignature(@RequestBody PerformanceSignaturePdaQuery performanceSignaturePdaQuery) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(performanceSignaturePdaQuery);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/construction/performanceSignature", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员审批启动数据
     * @return
     */
    @PostMapping("/complement/approvalConstructionStartFlowLog")
    public Object approvalConstructionStartFlowLog(@RequestBody List<ConstructionStartFlowLogComplementQuery> queryList, String projectNo) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(queryList);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/approvalConstructionStartFlowLog?projectNo="+projectNo, HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     *  定员撤回启动数据
     */
    @PostMapping("/withdrawSignature")
    public Object withdrawSignature(@RequestBody StartConfirmationQuery startConfirmationQuery) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(startConfirmationQuery);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/withdrawSignature", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员查看启动单列表
     * @return
     */
    @GetMapping("/complement/getConstructionStartFlowLog")
    public Object getConstructionStartFlowLog(@RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getConstructionStartFlowLog?type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员通过项目号查询启动单审批详情
     * @param projectNo
     * @return
     */
    @GetMapping("/complement/getFlowLogByProjectNo")
    public Object getFlowLogByProjectNo(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getFlowLogByProjectNo?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员查看计划列表
     * @return
     */
    @GetMapping("/complement/getConstructionPlan")
    public Object getConstructionPlan(@RequestParam("type") String type, @RequestParam("state") String state) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getConstructionPlan?type="+type + "&state="+state, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员施工计划审批
     * @param
     * @return
     */
    @GetMapping("/appProjectPlan")
    public Object approvalProjectPlan(@RequestParam("projectNo") String projectNo,
                                 @RequestParam("status") String status,
                                 @RequestParam("approveUser") String approveUser,
                                 @RequestParam("signatureConfirming") String signatureConfirming,
                                 String dismissReason) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/appProjectPlan?projectNo="+projectNo+"&status="+status+"&approveUser="+approveUser+"&signatureConfirming="+signatureConfirming+"&dismissReason="+dismissReason, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员查看问题录入项目
     * @param
     * @return
     */
    @GetMapping("/questionEntryQuery")
    public Object questionEntryQuery(@RequestParam("loginName") String loginName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/questionEntryQuery?loginName="+loginName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员通过查询到的项目中平台ID获取甲板
     * @param
     * @return
     */
    @GetMapping("/getDeckList")
    public Object getDeckList(@RequestParam("platformId") String platformId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getDeckList?platformId="+platformId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员待评价列表
     * @return
     */
    @GetMapping("/complement/getEvaluatedList")
    public Object getEvaluatedList(@RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getEvaluatedList?type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 完工报告列表
     * @return
     */
    @GetMapping("/complement/getCompletionReportList")
    public Object getCompletionReportList(@RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getCompletionReportList?type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 完工报告查看详情
     * @return
     */
    @GetMapping("/complement/getCompletionReportDetail")
    public Object getCompletionReportDetail(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getCompletionReportDetail?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 文档完整性确认列表
     * @return
     */
    @GetMapping("/complement/getIntegrityDocumentationList")
    public Object getIntegrityDocumentationList(@RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getIntegrityDocumentationList?type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 文档完整性查看详情
     * @return
     */
    @GetMapping("/complement/getIntegrityDocumentationDetail")
    public Object getIntegrityDocumentationDetail(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getIntegrityDocumentationDetail?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 文档完整性计控师确认
     */
    @GetMapping("/complement/integrityDocumentationConfirm")
    public Object integrityDocumentationConfirm(@RequestParam("id") String id) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/integrityDocumentationConfirm?id="+id, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工前检查PDA录入，修改、承包商/定员
     * @return
     */
    @PostMapping("/complement/savePreConstructionInspection")
    public Object savePreConstructionInspection(@RequestBody PreConstructionInspectionDto preConstructionInspectionDto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(preConstructionInspectionDto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/savePreConstructionInspection", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工前检查PDA定员查询项目
     * @return
     */
    @PostMapping("/complement/getWorkName")
    public Object getWorkName(@RequestParam("loginName") String loginName) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(loginName);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getWorkName", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 施工前检查PDA查看
     * @return
     */
    @GetMapping("/complement/getPreConstructionInspection")
    public Object getPreConstructionInspection(@RequestParam("projectNo") String projectNo,
                                                                        @RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getPreConstructionInspection?projectNo="+projectNo+"&type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 个人中心
     * @return
     */
    @GetMapping("/complement/getProcessInformation")
    public Object getProcessInformation(@RequestParam("loginName") String loginName,
                                                                        @RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getProcessInformation?loginName="+loginName+"&type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询大事件节点日志详情
     * @param projectNo
     * @return
     */
    @GetMapping("/complement/getConstructionNodeLogs")
    public Object getConstructionNodeLogs(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getConstructionNodeLogs?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员首页待办
     * @param loginName
     * @return
     */
    @GetMapping("/complement/getComplementBacklogNumber")
    public Object getComplementBacklogNumber(@RequestParam("loginName") String loginName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/complement/getComplementBacklogNumber?loginName="+loginName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商首页待办
     * @param projectNo
     * @return
     */
    @GetMapping("/complement/getContractorBacklogNumber")
    public Object getContractorBacklogNumber(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getContractorBacklogNumber?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员消息查询
     * @param loginName
     * @return
     */
    @GetMapping("/complement/getComplementMessage")
    public Object getComplementMessage(@RequestParam("loginName") String loginName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getComplementMessage?loginName="+loginName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商消息查询
     * @param projectNo
     * @return
     */
    @GetMapping("/complement/getContractorMessage")
    public Object getContractorMessage(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getContractorMessage?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员消息数量
     * @param loginName
     * @return
     */
    @GetMapping("/complement/getComplementMessageCount")
    public Object getComplementMessageCount(@RequestParam("loginName") String loginName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getComplementMessageCount?loginName="+loginName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商消息数量
     * @param projectNo
     * @return
     */
    @GetMapping("/complement/getContractorMessageCount")
    public Object getContractorMessageCount(@RequestParam("projectNo") String projectNo) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/getContractorMessageCount?projectNo="+projectNo, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 消息变更为已读
     * @param id
     * @return
     */
    @GetMapping("/complement/messageRead")
    public Object messageRead(@RequestParam("id") String id) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/messageRead?id="+id, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 正在施工列表
     * @return
     */
    @GetMapping("/complement/constructionList")
    public Object constructionList(String platformId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/complement/constructionList?platformId="+platformId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 通过项目ID查询布控球与测爆仪
     * @return
     */
    @GetMapping("/getConstructionStartConfig")
    public Object getConstructionStartConfig(String projectId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/getConstructionStartConfig?projectId="+projectId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 关闭项目
     */
    @GetMapping("/directorClosesProject")
    public Object directorClosesProject(@RequestParam("id") String id, @RequestParam("directorSignature") String directorSignature) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/directorClosesProject?id="+id+"&directorSignature="+directorSignature, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商/定员通过项目号查询日报列表
     */
    @GetMapping("/queryDailyListByProjectNo")
    public Object queryDailyListByProjectNo(@RequestParam("projectNo") String projectNo,
                                            @RequestParam("status") String status,
                                            @RequestParam("platform") String platform,
                                                                         @RequestParam("pageSize") Integer pageSize,
                                                                         @RequestParam("pageNum") Integer pageNum) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryDailyListByProjectNo?projectNo="+projectNo+"&status="+status+"&platform="+platform+"&pageSize="+pageSize+"&pageNum="+pageNum, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 通过日报ID查询日报详情
     * @param
     * @return
     */
    @GetMapping("/queryDailyById")
    public Object queryDailyById(@RequestParam("constructionDailyReportId") String constructionDailyReportId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryDailyById?constructionDailyReportId="+constructionDailyReportId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员日报驳回
     * @param constructionDailyReportId
     * @return
     */
    @GetMapping("/approveDailyById")
    public Object approveDailyById(@RequestParam("constructionDailyReportId") String constructionDailyReportId,
                              @RequestParam("remarks") String remarks,
                              @RequestParam("createUser") String createUser) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/approveDailyById?constructionDailyReportId="+constructionDailyReportId+"&remarks="+remarks+"&createUser="+createUser, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员查询所有的项目日报集合
     */
    @GetMapping("/queryDailyList")
    public Object queryDailyList(@RequestParam("loginName") String loginName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryDailyList?loginName="+loginName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商施工日报新增查询数据
     */
    @GetMapping("/saveDailyQuery")
    public Object saveDailyQuery(@RequestParam("projectNo") String projectNo
            , @RequestParam("fillingTime") String fillingTime
            , @RequestParam("platform") String platform) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/saveDailyQuery?projectNo="+projectNo+"&fillingTime="+fillingTime+"&platform="+platform, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商新增/编辑提交日报
     */
    @PostMapping("/saveConstructionDailyReport")
    public Object saveConstructionDailyReport(@RequestBody ConstructionDailyReportDto constructionDailyReportDto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(constructionDailyReportDto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/saveConstructionDailyReport", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 考勤主页
     * @param constructionStartId
     * @return
     */
    @GetMapping("/getConstructionAttebdabce")
    public Object getConstructionAttebdabce(@RequestParam("constructionStartId") String constructionStartId){
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getConstructionAttebdabce?constructionStartId="+constructionStartId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 定员考勤列表
     */
    @GetMapping("/constructionAttebdabceList")
    public Object constructionAttebdabceList(@RequestParam("status") String status) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/constructionAttebdabceList?status="+status, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 考勤详情
     * @param attendanceId
     * @param year
     * @param month
     * @return
     */
    @GetMapping("/getAttendanceDetails")
    public Object getAttendanceDetails(@RequestParam("attendanceId") String attendanceId,
                                  @RequestParam("year") String year,
                                  @RequestParam("month") String month){
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getAttendanceDetails?attendanceId="+attendanceId+"&year="+year+"&month="+month, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 保存考勤详细数据
     * @param constructionAttebdabceDetailInteractive
     * @return
     */
    @PostMapping("/updateAttebdabceDetail")
    public Object updateAttebdabceDetail(@RequestBody ConstructionAttebdabceDetailInteractive constructionAttebdabceDetailInteractive) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(constructionAttebdabceDetailInteractive);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/updateAttebdabceDetail", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 承包商考勤修改保存
     * @param constructionAttebdabceDetailList
     * @return
     */
    @PostMapping("/modifyAttendance")
    public Object modifyAttendance(@RequestBody List<ConstructionAttebdabceDetail> constructionAttebdabceDetailList) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(constructionAttebdabceDetailList);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/modifyAttendance", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 暂停施工/启动施工
     * @param constructionAttebdabceId
     * @return
     */
    @GetMapping("/suspensionConstruction")
    public Object suspensionConstruction(@RequestParam("constructionAttebdabceId") String constructionAttebdabceId, @RequestParam("type") String type) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/suspensionConstruction?constructionAttebdabceId="+constructionAttebdabceId+"&type="+type, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * @Name: 查询施工人员列表
     * @Description: 查询施工人员列表
     */
    @GetMapping("/getBuilderList")
    public Object getBuilderList(@RequestParam("name") String name, @RequestParam("platformId") String platformId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getBuilderList?name="+name+"&platformId="+platformId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询安全教育内容
     */
    @GetMapping("/queryConstructionEducation")
    public Object queryConstructionEducation(@RequestParam("assignmentsSection") String assignmentsSection, @RequestParam("educationType") String educationType, String startId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryConstructionEducation?assignmentsSection="+assignmentsSection+"&educationType="+educationType+"&startId="+startId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询安全教育首页完成情况
     */
    @GetMapping("/queryEducationCompletionStatus")
    public Object queryEducationCompletionStatus(@RequestParam("startId") String startId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryEducationCompletionStatus?startId="+startId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询安全教育人员列表
     */
    @GetMapping("/queryConstructionEducationPersonList")
    public Object queryConstructionEducationPerson(@RequestParam("startId") String startId, @RequestParam("educationType") String educationType) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryConstructionEducationPersonList?startId="+startId+"&educationType="+educationType, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 更新安全教育人员信息
     */
    @PostMapping("/updateConstructionEducationDetail")
    public Object updateConstructionEducationDetail(@RequestBody ConstructionEducationDetailDto constructionEducationDetailDto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(constructionEducationDetailDto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/updateConstructionEducationDetail", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询安全教育人员信息
     * @param constructionEducationDetailId
     * @return
     */
    @GetMapping("/getConstructionEducationDetail")
    public Object getConstructionEducationDetail(@RequestParam("constructionEducationDetailId") String constructionEducationDetailId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getConstructionEducationDetail?constructionEducationDetailId="+constructionEducationDetailId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 提交安全教育
     */
    @GetMapping("/submitConstructionEducationPersonList")
    public Object submitConstructionEducationPersonList(@RequestParam("startId") String startId, @RequestParam("educationType") String educationType, @RequestParam("contractorSignature") String contractorSignature) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/submitConstructionEducationPersonList?startId="+startId+"&educationType="+educationType+"&contractorSignature="+contractorSignature, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 安全教育、培训学习记录表内容补充提交
     */
    @PostMapping("/saveConstructionEducation")
    public Object saveConstructionEducation(@RequestBody List<Map<String, String>> mapList, @RequestParam("startId") String startId) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(mapList);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/saveConstructionEducation?startId="+startId, HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * PDA获取布控球信息数据
     */
    @GetMapping("/queryMonitorBallList")
    public Object queryMonitorBallList() {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/queryMonitorBallList", HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    @GetMapping("/queryPlatformByAdministrationCenter")
    public Object queryPlatformByAdministrationCenter(@RequestParam("administrationCenterId") String administrationCenterId,
                                                      @RequestParam("state") String state) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "system/queryPlatformByAdministrationCenter?administrationCenterId=" + administrationCenterId + "&state="+state, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    @GetMapping("/queryUserByPlatformId")
    public Object queryUserByPlatformId(String platformId) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "system/queryUserByPlatformId?platformId=" + platformId, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 保存文档完整性数据（上传）
     */
    @GetMapping("/saveDocumentIntegrity")
    public Object saveDocumentIntegrity(@RequestParam("file") String file,
                                        @RequestParam("constructionNodeExecuteId") String constructionNodeExecuteId,
                                        @RequestParam("userName") String userName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "/constructionPda/saveDocumentIntegrity?file="+file+"&constructionNodeExecuteId="+constructionNodeExecuteId+"&userName="+userName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }
    /**
     * 保存文档完整性数据（上传）
     */
    @GetMapping("/selectDocumentIntegrityTreeByPrjectNo")
    public Object selectDocumentIntegrityTreeByPrjectNo(@RequestParam("projectNo") String projectNo, @RequestParam("type") String type,@RequestParam(value = "userName",required = false) String userName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/selectDocumentIntegrityTreeByPrjectNo?projectNo="+projectNo+"&type="+type+"&userName="+userName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }


    /**
     * 文档完整性 查询项目列表
     */
    @GetMapping("/getConstructionPlatformList")
    public Object getConstructionPlatformList(@RequestParam(value = "userName",required = false) String userName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getConstructionPlatformList?userName="+userName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }



    /**
     * 文档完整性 查询项目列表
     */
    @GetMapping("/getConstructionStartById")
    public Object getConstructionStartById(@RequestParam(value = "id") String id) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url +
                    "constructionPda/getConstructionStartById?id="+id, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询施工信息
     */
    @PostMapping("/getConstructionList")
    public Object saveConstructionEducation(@RequestBody JSONObject dto) {
        try {
//            String json = mapper.writeValueAsString(mapList);
            String json = JSONObject.toJSONString(dto);
            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "constructionPda/getConstructionList", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }
}
