package com.cnooc.edgeapp.controller;

import com.cnooc.edgeapp.dto.DrillPic;
import com.cnooc.edgeapp.dto.DrillProcess;
import com.cnooc.edgeapp.dto.DrillRecord;
import com.cnooc.edgeapp.dto.PersonnelCollectState;
import com.cnooc.edgeapp.service.LoginService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;

/**
 * ContingencyManagementPdaController
 *
 * @author mtx
 * @date 2022/11/10 16:13
 */
@RestController
@RequiredArgsConstructor
@RequestMapping
public class ContingencyManagementPdaController {
    private static final Logger log = LoggerFactory.getLogger(ConstructionPdaController.class);

    @Value("${url}")
    public String url;

    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    @Autowired
    private LoginService loginService;

    /**
     * 获取演习计划
     *
     * @param platform 平台
     * @param pageNum  开始页数
     * @param pageSize 每页条数
     * @return R
     * @author mtx
     * @date 2022/11/10 18:42
     */
    @GetMapping("/drillPlan/queryList")
    public Object getPdaDrillPlanList(@RequestParam(name = "platform", required = true) String platform,
                                 @RequestParam(name = "pageNum", required = true) int pageNum,
                                 @RequestParam(name = "pageSize", required = true) int pageSize) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "/drillPlan/queryList?platform="+platform + "&pageNum=" + pageNum + "&pageSize=" + pageSize, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    /**
     * 保存签字照片
     *
     * @param drillPlan 演习计划
     * @return R
     * @author mtx
     * @date 2022/11/10 17:28
     */
    @PostMapping("/drillPlan/saveSignPic")
    public Object saveSignPic(@RequestBody DrillRecord drillPlan) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(drillPlan);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "/drillPlan/saveSignPic", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 上传现场照片及描述
     *
     * @param drillPic 图片
     * @return R
     * @author mtx
     * @date 2022/11/10 17:30
     */
    @PostMapping("/drillPlan/saveDrillPic")
    public Object saveDrillPic(@RequestBody DrillPic drillPic) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(drillPic);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "/drillPlan/saveDrillPic", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 上报实到人数
     *
     * @param personnelCollectState 人数信息
     * @return R
     * @author mtx
     * @date 2022/11/10 17:31
     */
    @PostMapping("/drillPlan/reportedNum")
    public Object reportedNum(@RequestBody PersonnelCollectState personnelCollectState) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(personnelCollectState);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "/drillPlan/reportedNum", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 获取集合记录
     *
     * @param recordId 演习计划id
     * @param boatName 艇名称
     * @return R
     * @author mtx
     * @date 2022/11/10 17:31
     */
    @GetMapping("/pda/drillPlan/queryPersonnelCollectState")
    public Object queryPersonnelCollectState(@RequestParam(name = "recordId", required = true) String recordId,
                                        @RequestParam(name = "boatName", required = true) String boatName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "/pda/drillPlan/queryPersonnelCollectState?recordId="+recordId + "&boatName=" + boatName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    /**
     * 获取演习过程
     *
     * @param recordId 演习计划id
     * @return R
     * @author mtx
     * @date 2022/11/10 17:32
     */
    @GetMapping("/pda/drillPlan/queryDrillProcess")
    public Object queryDrillProcess(@RequestParam(name = "recordId", required = true) String recordId) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "/pda/drillPlan/queryDrillProcess?recordId="+recordId, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    /**
     * 确认演习过程
     *
     * @param drillProcess 演习过程
     * @return R
     * @author mtx
     * @date 2022/11/10 17:32
     */
    @PostMapping("/drillPlan/confirmationExercise")
    public Object confirmationExercise(@RequestBody DrillProcess drillProcess) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(drillProcess);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "/drillPlan/confirmationExercise", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    @GetMapping("/drillPlan/getMessageBoxCount")
    public Object getMessageBoxCount(@RequestParam("platform") String platform,
                                         @RequestParam("userName") String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "/drillPlan/getMessageBoxCount?platform="+platform + "&userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

}
