package com.cnooc.edgeapp.controller;

import com.cnooc.edgeapp.domain.R;
import com.cnooc.edgeapp.dto.MassageDto;
import com.cnooc.edgeapp.service.LoginService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@Slf4j
@RestController
@CrossOrigin
public class LoginController {

    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    //敏态地址调用
    @Value("${url}")
    public String url;
    @Value("${client_base64}")
    public String client_base64;

    private LoginService loginService;

    public LoginController(LoginService loginService) {
        this.loginService = loginService;
    }

    /**
     * 登录验证 获取云端 token
     * @param username
     * @param request
     * @param response
     * @return
     */
    @GetMapping("/getCode")
    public Object loginVerify(@RequestParam(value = "username",required = false) String username ,HttpServletRequest request,HttpServletResponse response ) throws IOException {
           return loginService.loginVerify(username,request,response);
    }

    /**
     * 退出登录
     * @param request
     * @param response
     * @return
     */
    @GetMapping("/outLogin")
    public Object outLogin(HttpServletRequest request,HttpServletResponse response){
        return loginService.outLogin(request,response);
    }

    /**
     * 根据登录用户获取有权限访问的菜单
     * @param username
     * @return
     */
    @GetMapping("/getUserOfMenus")
    public R<Object> getUserOfMenus(@RequestParam("username") String username,@RequestParam("companyCode")String companyCode){
        return R.ok(loginService.getUserOfMenus(username,companyCode));
    }


    /**
     * 查询指定用户在指定公司下是否拥有指定菜单及其菜单操作的权限
     * @param username
     * @return
     */
    @GetMapping("/getUserOfMenusAndOperate")
    public R<Object> getUserOfMenusAndOperate(@RequestParam("username") String username
            ,@RequestParam("companyCode")String companyCode
            ,@RequestParam("menuCode")String menuCode){
        return R.ok(loginService.getUserOfMenusAndOperate(username,companyCode,menuCode));
    }


    /**
     * 查询指定用户在指定公司下是否拥有指定菜单及其菜单操作的权限
     * 10.120.97.206:8080/apps/niujie-shigong/sendMessage?businessCode=F0431CC19A3F&businessName=%E6%96%BD%E5%B7%A5%E7%AE%A1%E7%90%86&rangeType=STAFF&codes=admin&protocol=email&contentStr=1&text=%E6%A0%87%E9%A2%98,%E6%AD%A3%E6%96%87;%E6%A0%87%E9%A2%98,%E6%AD%A3%E6%96%87&code=5cc37056eb8328f58b11826f52f11dad&state=1
     * @param businessCode 消息发送方业务编号
     * @param businessName 消息发送方业务编号
     * @param rangeType 接收人范围类型：STAFF=人员、POSITION=岗位、DEPARTMENT=部门、ROLE=角色
     * @param codes 当指定为STAFF、POSITION、DEPARTMENT、ROLE对应的编码
     * @param protocol Items Enum: "stationLetter" "email"
     * @param contentStr
     * @param text
     * @return
     */
    @GetMapping("/sendMessage")
    public R<Object> sendMessage(@RequestParam("businessCode") String businessCode
            , @RequestParam("businessName") String businessName
            , @RequestParam("rangeType") String rangeType
            , @RequestParam("codes") String codes
            , @RequestParam("protocol") String protocol
            , @RequestParam("contentStr") String contentStr
            , @RequestParam("text") String text
    ){
        return R.ok(loginService.sendMessage(businessCode,businessName,rangeType,codes,protocol,contentStr,text));
    }


    /**
     * 查询指定用户在指定公司下是否拥有指定菜单及其菜单操作的权限
     * @param businessCode 消息发送方业务编号
     * @param businessName 消息发送方业务编号
     * @param topicCode  主题编号
     * @param protocols Items Enum: "stationLetter" "email"
     * @param param 主题关键字(模板变量)
     * @param rangeType 接收人范围类型：STAFF=人员、POSITION=岗位、DEPARTMENT=部门、ROLE=角色
     * @param codes 当指定为STAFF、POSITION、DEPARTMENT、ROLE对应的编码
     * @return
     */
    @PostMapping("/sendTopicMessage")
    public R<Object> sendTopicMessage(@RequestBody MassageDto dto){
        return R.ok(loginService.sendTopicMessage(dto));
    }

    /**
     * 获取用户详情
     * @param userName 用户编号
     * @return
     */
    @GetMapping("/getUserNubmer")
    public R<Object> getUserNubmer(@RequestParam("userName") String userName){
        return R.ok(loginService.getUserNubmer(userName));
    }

    /**
     * 通过人员查询岗位
     * @param userName
     * @return
     */
    @GetMapping("/queryJobByUserName")
    public Object queryJobByUserName(@RequestParam("userName") String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "system/queryJobByUserName?userName="+userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }
}
