package com.cnooc.edgeapp.controller;

import com.alibaba.fastjson.JSONObject;
import com.cnooc.edgeapp.service.LoginService;
import com.cnooc.edgeapp.utlis.MinioUtils;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.rendering.PDFRenderer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import javax.servlet.http.HttpServletResponse;
import java.awt.image.BufferedImage;
import java.io.*;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Base64;
import java.util.Collections;
import java.util.List;


@RestController
@RequiredArgsConstructor
@RequestMapping("/minio")
@Slf4j
@CrossOrigin
public class MinioController {

    @Value("${url}")
    public String url;

    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    @Autowired
    private LoginService loginService;

    @Autowired
    private MinioUtils minioUtils;

    /**
     * 上传
     *
     * @param file
     * @return
     */
    @PostMapping("/upload")
    @ResponseBody
    public Object upload(@RequestParam(name = "file", required = false) MultipartFile file, @RequestParam("moduleName") String moduleName) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            File f = File.createTempFile("app-", file.getOriginalFilename());
            file.transferTo(f);

            MultiValueMap<String, Object> formDataMap = new LinkedMultiValueMap();
            FileSystemResource fs = new FileSystemResource(f);//重点 这个才是restTemplate能传递的实体
            formDataMap.put("file", Collections.singletonList(fs));
            formDataMap.add("moduleName", moduleName);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.MULTIPART_FORM_DATA);
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<>(formDataMap, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "minio/upload", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 获得minio上的文件
     *
     * @param fileName 文件全名
     * @return
     */
    @PostMapping("/getImageOfMinio")
    public Object getImageOfMinio(@RequestParam(value = "fileName") String fileName) {
        fileName = fileName.split(":")[0];
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(fileName);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "minio/getImageOfMinio?fileName=" + fileName, HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 语音转地址
     *
     * @param url
     * @return
     */
    @GetMapping("/uploadUrl")
    public Object uploadUrl(@RequestParam("url") String url, @RequestParam("moduleName") String moduleName) {
        log.info("地址：{}", url);
        if (StringUtils.isNotBlank(url)) {
            URLConnection urlConnection = null;
            InputStream inputStream = null;
            try {
                URL u = new URL(url);
                urlConnection = u.openConnection();
                inputStream = urlConnection.getInputStream();
                return minioUtils.uploadFileInput(inputStream, url, moduleName);
            } catch (Exception e) {
                throw new RuntimeException(e);
            }

        }
        return null;
    }

    /**
     * 下载文件
     *
     * @param fileUrl  文件绝对路径
     * @param response
     * @throws IOException
     */
    @GetMapping("downloadFileOfMinio")
    public void downloadFileOfMinio(String fileUrl, HttpServletResponse response) throws IOException {
        if (StringUtils.isBlank(fileUrl)) {
            response.setHeader("Content-type", "text/html;charset=UTF-8");
            String data = "文件下载失败";
            OutputStream ps = response.getOutputStream();
            ps.write(data.getBytes("UTF-8"));
            return;
        }

        try {
            // 拿到文件路径
            int index = fileUrl.indexOf("/");
            index = fileUrl.indexOf("/", index + 1);
            String bucketName = fileUrl.substring(1, index);
            String url = fileUrl.substring(index + 1);
            // 获取文件对象
            InputStream object = minioUtils.getObject(bucketName, url);
            byte[] buf = new byte[1024];
            int length = 0;
            response.reset();
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode(url.substring(url.lastIndexOf("/") + 1), "UTF-8"));
            response.setContentType("application/octet-stream");
            response.setCharacterEncoding("UTF-8");
            OutputStream outputStream = response.getOutputStream();
            // 输出文件
            while ((length = object.read(buf)) > 0) {
                outputStream.write(buf, 0, length);
            }
            // 关闭输出流
            outputStream.close();
        } catch (Exception ex) {
            response.setHeader("Content-type", "text/html;charset=UTF-8");
            String data = "文件下载失败";
            OutputStream ps = response.getOutputStream();
            ps.write(data.getBytes("UTF-8"));
        }
    }

    /**
     * pdfbase64转图片 * @param pdfBase64 * @return
     */
    @PostMapping("/pdfToImg")
    public List<String> pdfToImg(@RequestBody String pdfBase64) {
        ByteArrayOutputStream os = new ByteArrayOutputStream();
        List<String> imgs = new ArrayList<>();
        try {
            InputStream is = new ByteArrayInputStream(Base64.getDecoder().decode(pdfBase64));
            PDDocument doc = PDDocument.load(is);
            PDFRenderer pdfRenderer = new PDFRenderer(doc);
            for (int i = 0; i < doc.getNumberOfPages(); i++) {
                BufferedImage image = pdfRenderer.renderImage(i, 1.25f);
                os = new ByteArrayOutputStream();
                ImageIO.write(image, "png", os);
                imgs.add("data:image/png;base64," + Base64.getEncoder().encodeToString(os.toByteArray()));
            }
        } catch (
                Exception e) {
            e.printStackTrace();
        }
        return imgs;
    }

}
