package com.cnooc.edgeapp.controller;

import com.alibaba.fastjson.JSONObject;
import com.cnooc.edgeapp.dto.MarkBasicSafetyDocumentDto;
import com.cnooc.edgeapp.dto.SelectDocumentDto;
import com.cnooc.edgeapp.entity.MarkBasicSafetyCategory;
import com.cnooc.edgeapp.entity.MarkBasicSafetyDocument;
import com.cnooc.edgeapp.query.ContractorLoginQuery;
import com.cnooc.edgeapp.service.LoginService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;










@RestController
@RequestMapping("/pdaBasic")
public class PdaBasicDocumentsController {

    private static final Logger log = LoggerFactory.getLogger(ConstructionPdaController.class);

    @Value("${url}")
    public String url;

    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    @Autowired
    private LoginService loginService;

    /**
     * 安全基础文档 -- 查询文档
     * @return
     */
    @PostMapping("/getDocumentList")
    public Object getDocumentList(@RequestBody MarkBasicSafetyDocumentDto markBasicSafetyDocumentDto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(markBasicSafetyDocumentDto);
            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "pdaBasic/getDocumentList", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 安全基础文档 -- 保存文档
     */
    @PostMapping("/saveDocument")
    public Object saveDocument(@RequestBody MarkBasicSafetyDocument document) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(document);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "pdaBasic/saveDocument", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 安全基础文档 -- 保存分类信息
     */
    @PostMapping("/saveCategory")
    public Object saveCategory(@RequestBody MarkBasicSafetyCategory category) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(category);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "pdaBasic/saveCategory", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }
    /**
     * 安全基础文档 -- 保存分类信息
     */
    @PostMapping("/selectDocumentList")
    public Object selectDocumentList(@RequestBody SelectDocumentDto dto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(dto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "pdaBasic/selectDocumentList", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 查询油田平台
     * @return
     */
    @GetMapping("/getOilGasFieByUserName")
    public Object getOilGasFieByUserName(String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = null;
        try {
            exchange = restTemplate.exchange(url + "pdaBasic/getOilGasFieByUserName?userName="+userName , HttpMethod.GET, entity, Object.class);
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
        return exchange;
    }
    /**
     * 查询快捷命名
     * @return
     */
    @GetMapping("/selectQuickName")
    public Object selectQuickName(@RequestParam("oilGasField") String oilGasField,@RequestParam("platformId") String platformId) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = null;
        try {
            exchange = restTemplate.exchange(url + "pdaBasic/selectQuickName?oilGasField="+oilGasField+"&platformId="+platformId , HttpMethod.GET, entity, Object.class);
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
        return exchange;
    }
}
