package com.cnooc.edgeapp.controller;

import com.alibaba.fastjson.JSONObject;
import com.cnooc.edgeapp.dto.*;
import com.cnooc.edgeapp.service.LoginService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.*;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;










@RestController
@RequestMapping("/pdaPatrol")
public class PdaPatrolOverallController {

    private static final Logger log = LoggerFactory.getLogger(ConstructionPdaController.class);

    @Value("${url}")
    public String url;

    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    @Autowired
    private LoginService loginService;

    /**
     * pda 查询巡检时间列表
     *
     * @param username
     * @return
     */
    @GetMapping("/getPdaPatrolTimeList")
    public Object getPdaPatrolTimeList(@RequestParam("username") String username) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getPdaPatrolTimeList?username=" + username, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * pda 查询巡检区域列表
     *
     * @param platform
     * @return
     */
    @GetMapping("/getPdaPatrolLocationList")
    public Object getPdaPatrolLocationList(@RequestParam("platform") String platform, @RequestParam("startTime") String time) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getPdaPatrolLocationList?platform=" + platform + "&startTime=" + time, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }


    /**
     * pda 巡检异常上报
     *
     * @param patrolRecord
     * @return
     */
    @PostMapping("/savePdaPatrolLocation")
    public Object savePdaPatrolLocation(@RequestBody PatrolRecord patrolRecord) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(patrolRecord);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/savePdaPatrolLocation", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }


    /**
     * pda 巡检打卡图片记录
     *
     * @param patrolRecordChart
     * @return
     */
    @PostMapping("/savePdaPatrolRecordChart")
    public Object savePdaPatrolRecordChart(@RequestBody PatrolRecordChart patrolRecordChart) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(patrolRecordChart);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/savePdaPatrolRecordChart", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException | RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }


    /**
     * pda 返回消息信息列表
     *
     * @param userName
     * @return
     */
    @GetMapping("/getMessageBoxSList")
    public Object getMessageBoxSList(@RequestParam("userName") String userName) {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getMessageBoxSList?userName=" + userName, HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }

    /**
     * 巡检消息数量
     *
     * @param loginName
     * @return
     */
    @GetMapping("/getMessageBoxCount")
    public Object getMessageBoxCount(@RequestParam("loginName") String loginName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getMessageBoxCount?loginName=" + loginName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * pda 自动打卡巡检
     *
     * @param userName
     * @return
     */
    @GetMapping("/nfcClockPatrol")
    public Object nfcClockPatrol(@RequestParam("nfcNo") String nfcNo
            , @RequestParam("userName") String userName
            , @RequestParam(value = "date", defaultValue = "", required = false) String date
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/nfcClockPatrol?nfcNo=" + nfcNo + "&userName=" + userName + "&date=" + date, HttpMethod.GET, entity, Object.class);
        return exchange;

    }

    /**
     * pda 自动打卡巡检
     *
     * @param userName
     * @return
     */
    @GetMapping("/nfcClockPatrolTimeOut")
    public Object nfcClockPatrolTimeOut(@RequestParam("nfcNo") String nfcNo
            , @RequestParam("userName") String userName
            , @RequestParam(value = "date", defaultValue = "", required = false) String date
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/nfcClockPatrolTimeOut?nfcNo=" + nfcNo + "&userName=" + userName + "&date=" + date, HttpMethod.GET, entity, Object.class);
        return exchange;

    }

    /**==========================================处理流程==============================================*/


    /**
     * 处理流程-获取打卡/视频巡检问题列表
     *
     * @param userName
     * @return
     */
    @GetMapping("/getProblemInformationList")
    public Object getProblemInformationList(@RequestParam("userName") String userName
            , @RequestParam("state") Integer state
            , @RequestParam(value = "type") Integer type
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getProblemInformationList?userName=" + userName + "&state=" + state + "&type=" + type, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * 处理流程-获取打卡/视频巡检检查列表列表
     *
     * @param userName
     * @return
     */
    @GetMapping("/getProblemInfoCheckList")
    public Object getProblemInfoCheckList(@RequestParam("userName") String userName, @RequestParam(value = "type") Integer type
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getProblemInfoCheckList?userName=" + userName + "&type=" + type, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    /**
     * 处理流程-获取打卡/视频巡检数量统计
     *
     * @param userName
     * @return
     */
    @GetMapping("/getProblemInfoCheckCount")
    public Object getProblemInfoCheckCount(@RequestParam("userName") String userName
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getProblemInfoCheckCount?userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * 处理流程-根据id获取 问题详情
     *
     * @param problemInfoId
     * @return
     */
    @GetMapping("/getProblemInfoById")
    public Object getProblemInfoById(@RequestParam("problemInfoId") String problemInfoId
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getProblemInfoById?problemInfoId=" + problemInfoId, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * 处理流程-临时整改措施
     *
     * @param param
     * @return
     */
    @PostMapping("/saveTemporary")
    public Object saveTemporary(@RequestBody SaveTemporaryParam param
    ) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/saveTemporary", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 处理流程-最终整改措施
     *
     * @param param
     * @return
     */
    @PostMapping("/saveFinal")
    public Object saveFinal(@RequestBody SaveFinalParam param
    ) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/saveFinal", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 处理流程-提交检查结果
     *
     * @param param
     * @return
     */
    @PostMapping("/saveVerify")
    public Object saveVerify(@RequestBody SaveVerifyParam param
    ) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/saveVerify", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 处理流程-指定处理人
     *
     * @param problemInfoId
     * @param appointProcessor
     * @return
     */
    @GetMapping("/designatedProcessor")
    public Object designatedProcessor(@RequestParam("problemInfoId") String problemInfoId
            , @RequestParam("appointProcessor") String appointProcessor
            , @RequestParam("userName") String userName
    ) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/designatedProcessor?problemInfoId=" + problemInfoId + "&appointProcessor=" + appointProcessor + "&userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * 处理流程-查询人员（专业树）
     *
     * @param userName
     * @return
     */
    @GetMapping("/getSysUserToMajor")
    public Object getSysUserToMajor(@RequestParam("userName") String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getSysUserToMajor?userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    /**
     * 处理流程-查询人员（pc查询专业树）
     *
     * @param userName
     * @return
     */
    @GetMapping("/getSysUserToMajorPc")
    public Object getSysUserToMajorPc(@RequestParam("userName") String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getSysUserToMajorPc?userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    /**
     * 定时更新执行表
     */
    @GetMapping("/addExecutionTableRegularly")
    private void addExecutionTableRegularly() {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/addExecutionTableRegularly", HttpMethod.GET, entity, Object.class);
    }


    /**
     * 查询异常点位
     *
     * @param userName
     * @return
     */
    @GetMapping("/getHseUnusualDrop")
    public Object getHseUnusualDrop(@RequestParam("userName") String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getHseUnusualDrop?userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * HSE-异常上报
     *
     * @param dto
     * @return
     */
    @PostMapping("/saveHseUnusual")
    public Object saveHseUnusual(@RequestBody HseUnusualDto dto) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(dto);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/saveHseUnusual", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }


    /**
     * HSE-查询全平台
     *
     * @param dto
     * @return
     */
    @GetMapping("/getAllPlatform")
    public Object getAllPlatform(@RequestParam("userName") String userName) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getAllPlatform?userName=" + userName, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    /**
     * HSE-查询当天已保存列表
     *
     * @param
     * @return
     */
    @PostMapping("/getHseDataList")
    public Object getHseDataList(@RequestBody GetHseDataParam param) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getHseDataList", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }


    @GetMapping("/audit/user-search")
    public Object user_search(@RequestParam("filter") String filter) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/audit/user-search?filter=" + filter, HttpMethod.GET, entity, Object.class);
        return exchange;
    }

    @PostMapping("/process/problem_flow_apply/start")
    public Object start(@RequestBody JSONObject param) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/process/problem_flow_apply/start", HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    @GetMapping("/instance/{instanceId}")
    public Object instance(@PathVariable("instanceId") String instanceId) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/instance/" + instanceId, HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    @PostMapping("/task/{taskId}/complete")
    public Object complete(@PathVariable("taskId") String taskId, @Validated @RequestBody JSONObject param) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/task/" + taskId + "/complete", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }

    @PostMapping("/task/{taskId}/reject")
    public Object reject(@PathVariable("taskId") String taskId, @Validated @RequestBody JSONObject param) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/task/" + taskId + "/reject", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }


    @PostMapping("/task/{taskId}/next-activities")
    public Object next_activities(@PathVariable("taskId") String taskId, @RequestBody JSONObject param) {
        ObjectMapper mapper = new ObjectMapper();
        try {
            String json = mapper.writeValueAsString(param);

            HttpHeaders httpHeaders = loginService.getAuthorization();
            httpHeaders.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity = new HttpEntity<>(json, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/task/" + taskId + "/next-activities", HttpMethod.POST, entity, Object.class);
            return exchange;
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
    }


    @GetMapping("/instance/{instanceId}/audit-info")
    public Object audit_info(@PathVariable("instanceId") String instanceId) {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/instance/" + instanceId + "/audit-info", HttpMethod.GET, entity, Object.class);
        return exchange;
    }


    @GetMapping("getAppVersion")
    public Object getAppVersion() {
        try {
            HttpHeaders httpHeaders = loginService.getAuthorization();
            MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
            HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
            ResponseEntity<Object> exchange = restTemplate.exchange(url + "samapp/pdaPatrol/getAppVersion", HttpMethod.GET, entity, Object.class);
            return exchange;
        } catch (RestClientException e) {
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
            return jsonObject;
        }
    }
}
