package com.cnooc.edgeapp.filter;


import cn.hutool.core.net.URLEncodeUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.bluetron.eco.sdk.api.SuposApi;
import com.bluetron.eco.sdk.dto.common.ApiResponse;
import com.bluetron.eco.sdk.dto.common.SuposConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import javax.servlet.*;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Slf4j
//@Component
public class AuthFilter implements Filter {
    private final static String FILE_JS = ".js";
    private final static String FILE_CSS = ".css";
    private final static String FILE_WOFF = ".png";
    private final static String FILE_TTF = ".ttf";
    private final static String FILE_HTML = ".html";
    @Value("${app.logout}")
    private String logout;
    @Value("${app.white-list}")
    private String whiteList;
    @Value("${app.id}")
    private String appId;
    @Value("${app.deploy}")
    private Boolean deploy;

    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
        HttpServletRequest request = (HttpServletRequest) servletRequest;
        HttpServletResponse response = (HttpServletResponse) servletResponse;
        log.info(request.getRequestURL().toString());

        //对静态资源直接放行
        if (request.getRequestURI().contains(FILE_CSS) || request.getRequestURI().contains(FILE_JS) || request.getRequestURI().contains(FILE_WOFF) || request.getRequestURI().contains(FILE_TTF) || request.getRequestURI().contains(FILE_HTML)) {
            filterChain.doFilter(servletRequest, servletResponse);
            return;
        }
        //白名单地址直接放行
        String[] excludeUris = whiteList.split(";");
        if (excludeUris != null && excludeUris.length > 0) {
            for (int i = 0; i < excludeUris.length; i++) {
                Pattern p = Pattern.compile(excludeUris[i]);
                Matcher matcher = p.matcher(request.getRequestURI());
                boolean matched = matcher.find();
                if (matched) {
                    filterChain.doFilter(servletRequest, servletResponse);
                    return;
                }
            }
        }
        //获取凭证cookie
        Cookie authorize = getCookieByName(request, "authorize");
        //默认无登录凭证
        boolean oauthValid = false;
        //cookie不为空
        if (!Objects.isNull(authorize)) {
            HttpSession session = request.getSession();
            JSONObject token = (JSONObject) session.getAttribute(authorize.getValue());
            // 凭证有效
            if (!Objects.isNull(token)) {
                oauthValid = true;
            }
        }
        if (!oauthValid) {
            //从url中获取授权码参数
            String code = request.getParameter("code");
            log.info("code:{}", code);
            //如果授权码参数为空
            if (!StringUtils.hasText(code)) {
                log.info("授权码为空。。。。。。。");
                //302跳转到supOS 获取授权码
                String location = SuposApi.authService.authorize(URLEncodeUtil.encodeAll(buildRedirectUrl(request)), "1");
                response.addHeader("Location", location);
                response.setStatus(HttpStatus.FOUND.value());
                return;
            } else {
                log.info("授权码换token。。。。。。。");
                //授权码不为空，则用授权码换取token 完成授权
                String id = UUID.randomUUID().toString();
                ApiResponse apiResponse = SuposApi.authService.accessToken(code, logout + "?code=" + id);
                if (apiResponse.getHttpCode() == 200) {
                    JSONObject result = JSONUtil.parseObj(apiResponse.getResponseBody());
                    //登录用户名
                    String username = result.getStr("username");
                    log.info("username:{}",username);
                    //关联的人员编码
                    String personCode = result.getStr("personCode");
                    log.info("personCode:{}",personCode);
                    //人员所属公司编码
                    String companyCode = result.getStr("companyCode");
                    log.info("companyCode:{}",companyCode);
                    String accessToken = result.getStr("accessToken");
                    log.info("accessToken:{}",accessToken);
                    String refreshToken = result.getStr("refreshToken");
                    log.info("refreshToken:{}",refreshToken);
                    //TODO 将supOS用户与应用用户关联
                    //TODO 应用自身的权限业务,此处相当于应用原来的登录成功后操作
                    //TODO 应用原先的登录后处理逻辑
                    HttpSession session = request.getSession();
                    session.setMaxInactiveInterval(1500);
                    session.setAttribute(id, result);
                    Cookie authorizeCookie = new Cookie("authorize", id);
                    authorizeCookie.setPath("/");
                    response.addCookie(authorizeCookie);
                } else {
                    log.info("授权码失效。。。。。。。");
                    //获取token失败，则删除请求url中旧的code及state后重新获取授权码
                    String location = SuposApi.authService.authorize(URLEncodeUtil.encodeAll(removeParam(buildRedirectUrl(request), Arrays.asList("code", "state"))), "1");
                    response.addHeader("Location", location);
                    response.setStatus(HttpStatus.FOUND.value());
                    return;
                }
            }
        }
        filterChain.doFilter(servletRequest, servletResponse);
    }


    private Cookie getCookieByName(HttpServletRequest request, String name) {
        Cookie[] cookies = request.getCookies();
        if (!Objects.isNull(cookies) && cookies.length > 0) {
            Optional<Cookie> optional = Arrays.stream(cookies).filter(x -> x.getName().equals(name)).findAny();
            if (optional.isPresent()) {
                return optional.get();
            }
        }
        return null;
    }

    private static String removeParam(String url, List<String> name) {
        for (String s : name) {
            // 使用replaceAll正则替换,replace不支持正则
            url = url.replaceAll("&?" + s + "=[^&]*", "");
        }
        if (url.endsWith("?")) {
            url = url.substring(0, url.length() - 1);
        }
        return url;
    }

    private String buildRedirectUrl(HttpServletRequest request) {
        StringBuffer redirect = new StringBuffer();
        String queryString = request.getQueryString();
        //如果部署到supOS
        if (deploy) {
            redirect.append(SuposConfig.getSuposApiAddress()).append("/apps/").append(appId).append(request.getRequestURI());
        } else {
            //本地调试
            redirect.append(request.getRequestURL());
        }
        if (StringUtils.hasText(queryString)) {
            redirect.append("?").append(queryString);
        }
        return redirect.toString();
    }
}
