package com.cnooc.edgeapp.utlis;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.cnooc.edgeapp.domain.R;
import com.cnooc.edgeapp.entity.FileUploadInputStream;
import com.cnooc.edgeapp.service.LoginService;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.minio.MinioClient;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;
import sun.misc.BASE64Encoder;

import javax.annotation.Resource;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.UUID;

/**
 * @Name: MinioUtils
 * @Description:
 * @Version: V1.0.0  （版本号）
 * @Author: cuiliang
 * @Create Date:2021/3/15
 */
@Component
@Slf4j
public class MinioUtils {

    @Autowired
    private MinioClient client;
    @Resource(name = "restTemplate1")
    RestTemplate restTemplate;

    @Value("${url}")
    public String urlPath;

    @Autowired
    private LoginService loginService;
    private final static String SAM = "oo-qhd-sam-agg/";

    /**
     * 创建bucket
     *
     * @param bucketName bucket名称
     */
    @SneakyThrows
    public void createBucket(String bucketName) {
        if (!client.bucketExists(bucketName)) {
            client.makeBucket(bucketName);
        }
    }

    public Object uploadFileInput(InputStream in, String url, String moduleName) throws Exception {
        HttpHeaders httpHeaders = loginService.getAuthorization();
        MultiValueMap<String, Object> formdate = new LinkedMultiValueMap<>();
        HttpEntity<MultiValueMap<String, Object>> entity = new HttpEntity<MultiValueMap<String, Object>>(formdate, httpHeaders);
        ResponseEntity<Object> exchange = null;
        try {
            //exchange = restTemplate.exchange(urlPath + "minio/getUploadConfig?fileType=mp3", HttpMethod.POST, entity, Object.class);

            //Object obj = exchange.getBody();
            //R r = JSON.parseObject(JSON.toJSONString(obj), R.class);
            String bucketName = "audio-qhd326";
            String suffer = ".mp3";

            // 判断存储桶是否存在
            //createBucket(bucketName);

            // 新的文件名 = 文件名称_时间戳.后缀名
            String fileName = "语音" + "_" + UUID.randomUUID().toString().replaceAll("-", "").trim() + suffer;
            // 开始上传
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            int len;
            byte[] bytes = new byte[1024];
            while ((len = in.read(bytes)) != -1) {
                byteArrayOutputStream.write(bytes, 0, len);
            }
            ObjectMapper mapper = new ObjectMapper();
            FileUploadInputStream fileUploadInputStream = new FileUploadInputStream();
            fileUploadInputStream.setFileName(fileName);
            fileUploadInputStream.setFileSize(in.available());
            fileUploadInputStream.setContentType("mp3");
            fileUploadInputStream.setBytes(byteArrayOutputStream.toByteArray());
            String json = mapper.writeValueAsString(fileUploadInputStream);
            HttpHeaders httpHeaders1 = loginService.getAuthorization();
            httpHeaders1.setContentType(MediaType.APPLICATION_JSON);
            HttpEntity<String> entity1 = new HttpEntity<>(json, httpHeaders1);
            ResponseEntity<Object> exchange1 = restTemplate.exchange(urlPath + "minio/uploadForInputStream", HttpMethod.POST, entity1, Object.class);
            return exchange1;
        } catch (RestClientException e) {
            e.printStackTrace();
            String message = e.getMessage();
            message = message.replaceAll("500 Internal Server Error: ", "");
            message = message.substring(1, message.length() - 1);
            JSONObject jsonObject = JSONObject.parseObject(message);
        }
        return "上传失败";
    }

    /**
     * 获得minio上的图片
     *
     * @param fileName
     * @return
     */
    public R<String> getImageOfMinio(String fileName) {
        InputStream input = null;
        ByteArrayOutputStream output = new ByteArrayOutputStream();
        byte[] buffer = new byte[1024 * 4];
        try {
            int index = fileName.indexOf("/");
            index = fileName.indexOf("/", index + 1);
            String bucketName = fileName.substring(1, index);
            String url = fileName.substring(index + 1);
            input = client.getObject(bucketName, url);
            int n = 0;
            while (-1 != (n = input.read(buffer))) {
                output.write(buffer, 0, n);
            }
            byte[] bytes = output.toByteArray();
            //对字节数组Base64编码
            BASE64Encoder encoder = new BASE64Encoder();
            String base64 = encoder.encode(bytes);
            String type = "audio/wav";
            if (!fileName.endsWith(".mp3")) {
                type = client.statObject(bucketName, url).contentType();
            }
            if (ObjectUtil.equal("application/octet-stream", type)) {
                String[] split = url.split("[.]");
                type = "application/" + split[split.length - 1];
            }
            if (ObjectUtil.equal("application/png", type)) {
                type = "image/jpeg";
            }
            if (ObjectUtil.equal("application/jpg", type)) {
                type = "image/jpeg";
            }
            if (ObjectUtil.equal("application/jpeg", type)) {
                type = "image/jpeg";
            }
            base64 = "data:" + type + ";" + "base64," + base64;
            return R.ok(base64);//返回Base64编码过的字节数组字符串
        } catch (Exception e) {
            e.printStackTrace();
            return R.fail("图片预览失败");
        } finally {
            if (input != null) {
                try {
                    input.close();
                } catch (IOException e) {
                    log.error(e.getMessage());
                }
            }
        }
    }

    /**
     * 获取文件
     *
     * @param bucketName bucket名称
     * @param objectName 文件名称
     * @return 二进制流
     */
    @SneakyThrows
    public InputStream getObject(String bucketName, String objectName) {
        return client.getObject(bucketName, objectName);
    }
}
